==> micro_kernel-0.1.tar.gz: micro_kernel-0.1/sys/syscall.h <==
/*
 * sys/syscall.h
 */


#ifndef share_syscall_h
#define share_syscall_h


// ƥॳ㳰٥
#define	SYSCALL_VECTOR 81

// ƥॳֹ
#define	SYS_OPEN						0
#define	SYS_EXEC						1
#define	SYS_READ						2
#define	SYS_WRITE						3
#define	SYS_CLOSE						4
#define	SYS_LSEEK						5
#define	SYS_MKDIR						6
#define	SYS_RENAME						7
#define	SYS_UNLINK						8
#define	SYS_RMDIR						9
#define	SYS_OPENDIR						10
#define	SYS_READDIR						11
#define	SYS_REWINDDIR					12
#define	SYS_CHDIR						13
#define	SYS_FCHDIR						14
#define	SYS_GETCWD						15
#define	SYS_LOCK						16
#define	SYS_MOUNT						17
#define	SYS_UMOUNT						18
#define	SYS_FORK						19
#define	SYS_EXIT						20
#define	SYS_SLEEP						21
#define	SYS_ALARM						22
#define	SYS_TIME						23
#define	SYS_GETTIMEOFDAY				24
#define	SYS_SYNC						25
#define	SYS_WAIT						26
#define	SYS_GETPID						27
#define	SYS_GETGID						28
#define	SYS_GETPGID						29
#define	SYS_GETPPID						30
#define	SYS_GETUID						31
#define	SYS_GETSID						32
#define	SYS_SETGID						33
#define	SYS_SETPGID						34
#define	SYS_SETUID						35
#define	SYS_SETSID						36
#define	SYS_TIMES						37
#define	SYS_SIGACTION					38
#define	SYS_SIGPROCMASK					39
#define	SYS_KILL						40
#define	SYS_SIGPENDING					41
#define	SYS_SIGSUSPEND					42
#define	SYS_STAT						43
#define	SYS_FSTAT						44
#define	SYS_LSTAT						45
#define	SYS_FCNTL						46
#define	SYS_BRK							47
#define	SYS_REBOOT						48
#define	SYS_IOCTL						49
#define	SYS_LINK						50
#define	SYS_SYMLINK						51
#define	SYS_READLINK					52
#define	SYS_SELECT						53
#define	SYS_POLL						54
#define	SYS_GETFSSTAT					55
#define	SYS_STATFS						56
#define	SYS_UNAME						57
#define	SYS_TTYNAME						58
#define	SYS_SETTIME						59
#define	SYS_SOCKET						60
#define	SYS_SEND						61
#define	SYS_RECV						62
#define	SYS_CONNECT						63
#define	SYS_SHUTDOWN					64
#define	SYS_BIND						65
#define	SYS_LISTEN						66
#define	SYS_ACCEPT						67
#define	SYS_GETSOCKNAME					68
#define	SYS_GETPEERNAME					69
#define	SYS_GETSOCKOPT					70
#define	SYS_SETSOCKOPT					71
#define	SYS_SENDMSG						72
#define	SYS_RECVMSG						73
#define	SYS_GETITIMER					74
#define	SYS_SETITIMER					75
#define	SYS_CHMOD						76
#define	SYS_FCHMOD						77
#define	SYS_CHOWN						78
#define	SYS_FCHOW						79
#define	SYS_UTIMES						80
#define	SYS_CALC_MICROSECONDS			81
#define	SYS_TEST						82
//**************************************
#define	SYS_SEND_CONSOLE				83
#define	SYS_COPY_FROM_USER				84
#define	SYS_SLEEP_MODULE				85
#define	SYS_DELETE_MODULE				86
#define	SYS_REGIST_MODULE				87
#define	SYS_ALLOC_CHRDEV_REGION			88
#define	SYS_UNREGISTER_CHRDEV_REGION	89
#define	SYS_CDEV_ADD					90
#define	SYS_INTHAND_ADD					91
#define	SYS_INTHAND_REMOVE				92
#define	SYS_INIT_WAITQUEU_HEAD			93
#define	SYS_WAIT_WAITQUEU				94
#define	SYS_WAIT_WAITQUEU_SIGNAL		95
#define	SYS_WAKE_WAITQUEU				96
#define	SYS_MICRO_DELAY					97
#define	SYS_MACHINE1					98
#define	SYS_INIT_MODULE					99
//**************************************
#define	SYS_PTHREAD_CREATE				100
#define	SYS_PTHREAD_EXIT				101
#define	SYS_PTHREAD_JOIN				102
//**************************************
#define	SYS_TSLEEP						103
#define	SYS_WAKEUP						104
//**************************************

#define	SYS_ENTRYS						105		/* ƥॳ륨ȥ꡼ */


#ifndef ASM_FILE


typedef int (*SYSCALL)();


#endif


#endif

==> micro_kernel-0.2.tar.gz: micro_kernel-0.2/sys/syscall.h <==
/*
 * sys/syscall.h
 */


#ifndef share_syscall_h
#define share_syscall_h


// ƥॳ㳰٥
#define	SYSCALL_VECTOR 81

// ƥॳֹ
#define	SYS_OPEN						0
#define	SYS_EXEC						1
#define	SYS_READ						2
#define	SYS_WRITE						3
#define	SYS_CLOSE						4
#define	SYS_LSEEK						5
#define	SYS_MKDIR						6
#define	SYS_RENAME						7
#define	SYS_UNLINK						8
#define	SYS_RMDIR						9
#define	SYS_OPENDIR						10
#define	SYS_READDIR						11
#define	SYS_REWINDDIR					12
#define	SYS_CHDIR						13
#define	SYS_FCHDIR						14
#define	SYS_GETCWD						15
#define	SYS_LOCK						16
#define	SYS_MOUNT						17
#define	SYS_UMOUNT						18
#define	SYS_FORK						19
#define	SYS_EXIT						20
#define	SYS_SLEEP						21
#define	SYS_ALARM						22
#define	SYS_TIME						23
#define	SYS_GETTIMEOFDAY				24
#define	SYS_SYNC						25
#define	SYS_WAIT						26
#define	SYS_GETPID						27
#define	SYS_GETGID						28
#define	SYS_GETPGID						29
#define	SYS_GETPPID						30
#define	SYS_GETUID						31
#define	SYS_GETSID						32
#define	SYS_SETGID						33
#define	SYS_SETPGID						34
#define	SYS_SETUID						35
#define	SYS_SETSID						36
#define	SYS_TIMES						37
#define	SYS_SIGACTION					38
#define	SYS_SIGPROCMASK					39
#define	SYS_KILL						40
#define	SYS_SIGPENDING					41
#define	SYS_SIGSUSPEND					42
#define	SYS_STAT						43
#define	SYS_FSTAT						44
#define	SYS_LSTAT						45
#define	SYS_FCNTL						46
#define	SYS_BRK							47
#define	SYS_REBOOT						48
#define	SYS_IOCTL						49
#define	SYS_LINK						50
#define	SYS_SYMLINK						51
#define	SYS_READLINK					52
#define	SYS_SELECT						53
#define	SYS_POLL						54
#define	SYS_GETFSSTAT					55
#define	SYS_STATFS						56
#define	SYS_UNAME						57
#define	SYS_TTYNAME						58
#define	SYS_SETTIME						59
#define	SYS_SOCKET						60
#define	SYS_SEND						61
#define	SYS_RECV						62
#define	SYS_CONNECT						63
#define	SYS_SHUTDOWN					64
#define	SYS_BIND						65
#define	SYS_LISTEN						66
#define	SYS_ACCEPT						67
#define	SYS_GETSOCKNAME					68
#define	SYS_GETPEERNAME					69
#define	SYS_GETSOCKOPT					70
#define	SYS_SETSOCKOPT					71
#define	SYS_SENDMSG						72
#define	SYS_RECVMSG						73
#define	SYS_GETITIMER					74
#define	SYS_SETITIMER					75
#define	SYS_CHMOD						76
#define	SYS_FCHMOD						77
#define	SYS_CHOWN						78
#define	SYS_FCHOW						79
#define	SYS_UTIMES						80
#define	SYS_CALC_MICROSECONDS			81
#define	SYS_TEST						82
//**************************************
#define	SYS_SEND_CONSOLE				83
#define	SYS_SET_CTLTERM					84
#define	SYS_SLEEP_MODULE				85
#define	SYS_DELETE_MODULE				86
#define	SYS_REGIST_MODULE				87
#define	SYS_SEND_SIGNAL_PGID			88
#define	SYS_SET_USER_IOMAP				89
#define	SYS_CDEVSW_ATTACH				90
#define	SYS_INTHAND_ADD					91
#define	SYS_INTHAND_REMOVE				92
#define	SYS_INTR_ESTABLISH				93
#define	SYS_INTR_DISESTABLISH			94
#define	SYS_IS_SET_CTLTERM				95
#define	SYS_WAKE_WAITQUEU				96
#define	SYS_MICRO_DELAY					97
#define	SYS_MACHINE1					98
#define	SYS_INIT_MODULE					99
//**************************************
#define	SYS_PTHREAD_CREATE				100
#define	SYS_PTHREAD_EXIT				101
#define	SYS_PTHREAD_JOIN				102
//**************************************
#define	SYS_TSLEEP						103
#define	SYS_WAKEUP						104
//**************************************

#define	SYS_ENTRYS						105		/* ƥॳ륨ȥ꡼ */


#ifndef ASM_FILE


typedef int (*SYSCALL)();


#endif


#endif
